==> myriad-laravel-authentication-0.0.19-9ab544.tar: src/Lib/Repositories/EloquentAccessTokenRepository.php <==
<?php

namespace Myriad\Authentication\Lib\Repositories;

use Myriad\Authentication\Lib\Repositories\IAccessTokenRepository;
use Myriad\Authentication\Models\AccessToken;
use Carbon\Carbon;
use Myriad\Authentication\Models\IAccessTokenOwner;
use Myriad\Authentication\Models\IAccessTokenClient;

class EloquentAccessTokenRepository implements IAccessTokenRepository
{
  public function createAccessToken($owner, $client) {
    $token = $this->generateToken();

    $tokenLifetime = config('authentication.access_token_expiration_days', 365);
    $expiresAt = Carbon::now()->addDays($tokenLifetime);

    return AccessToken::create([
      'token' => $token,
      'expires_at' => $expiresAt,
      'owner_type' => $owner->getMorphClass(),
      'owner_id' => $owner->id,
      'client_type' => $client->getMorphClass(),
      'client_id' => $client->id
    ]);
  }

  public function getUserFromToken($token) {
    $accessToken = $this->getAccessTokenByToken($token);

    if (is_null($accessToken)) {
      return null;
    }

    return $accessToken->owner;
  }

  public function getAccessTokenByToken($token, $expired = false) {
    $query = AccessToken::where('token', $token);
    if ($expired === false) {
      $query->where('expires_at', '>', \DB::raw('now()'));
    } else if ($expired === true) {
      $query->where('expires_at', '<=', \DB::raw('now()'));
    }
    return $query->first();
  }

  private function generateToken($bytes = 96) {
    $rand = random_bytes($bytes);
    $rand = base64_encode($rand);
    $rand = str_replace(['/', '+', '='], ['_', '-', '*'], $rand); // replace non-url safe characters
    return $rand;
  }

}

==> myriad-laravel-authentication-1.0.9.3-6b9b53.tar: src/Lib/Repositories/EloquentAccessTokenRepository.php <==
<?php

namespace Myriad\Authentication\Lib\Repositories;

use Carbon\Carbon;
use Myriad\Authentication\Models\AccessToken;
use Myriad\Authentication\Models\IAccessTokenClient;
use Myriad\Authentication\Models\IAccessTokenOwner;

class EloquentAccessTokenRepository implements IAccessTokenRepository {

  public function createAccessToken($owner, $client) {
    $token = $this->generateToken();

    $tokenLifetime = config('authentication.access_token_expiration_days', 365);
    $expiresAt = Carbon::now()->addDays($tokenLifetime);

    return AccessToken::create([
      'token' => $token,
      'expires_at' => $expiresAt,
      'owner_type' => $owner->getMorphClass(),
      'owner_id' => $owner->id,
      'client_type' => $client->getMorphClass(),
      'client_id' => $client->id
    ]);
  }

  public function getUserFromToken($token) {
    $accessToken = $this->getAccessTokenByToken($token);

    if (is_null($accessToken)) {
      return null;
    }

    return $accessToken->owner;
  }

  public function getAccessTokenByToken($token, $expired = false) {
    $query = AccessToken::where('token', $token);
    if ($expired === false) {
      $query->where('expires_at', '>', \DB::raw('now()'));
    } else if ($expired === true) {
      $query->where('expires_at', '<=', \DB::raw('now()'));
    }
    return $query->first();
  }

  public function logout($owner, $client, $all) {
    $query = AccessToken::query()
                        ->where('owner_id', $owner->id)
                        ->where('owner_type', $owner->getMorphClass())
                        ->where('client_type', $client->getMorphClass());
    if ($all === false) { //more strict null checking
      $query->where('client_id', $client->id);
    }

    $query->update(['expires_at' => \DB::raw('now()')]);
  }

  private function generateToken($bytes = 96) {
    $rand = random_bytes($bytes);
    $rand = base64_encode($rand);
    $rand = str_replace(['/', '+', '='], ['_', '-', '*'], $rand); // replace non-url safe characters
    return $rand;
  }

}
